# Release History

## 1.0.0 (08/29/2022)

- Initial Release

- Configured, CHANGELOG, LICENSE, and MANIFEST

- Connect to a FTPS server remotely

- Connect via hostname, port, username and password (optional SSL)

- Download, upload, delete, and move files on the FTPS server
